@@ -1,5 +1,5 @@
 package Azure::AD::Auth;
-  our $VERSION = '0.03';
+  our $VERSION = '0.04';
 1;
 ### main pod documentation begin ###
 
@@ -11,7 +11,7 @@ Azure::AD::Auth - Libraries for authenticating through Azure AD
 
 =head1 DESCRIPTION
 
-This set of modules helps you authenticated with Azure Active Directory. Note that
+This set of modules helps you authenticate with Azure Active Directory. Note that
 "Azure Active Directory" is not "Active Directory". Azure Active Directory is an
 online authentication service that speaks OAuth2, SAML and other protocols (and 
 doesn't speak LDAP, like traditional Active Directory"
@@ -23,8 +23,12 @@ flow:
 
 L<Azure::AD::ClientCredentials>
 
+L<Azure::AD::ClientCredentialsV2>
+
 L<Azure::AD::DeviceLogin>
 
+L<Azure::AD::Password>
+
 =head1 SEE ALSO
 
 L<https://docs.microsoft.com/en-us/azure/active-directory/develop/v2-protocols-oidc>
@@ -32,8 +36,11 @@ L<https://docs.microsoft.com/en-us/azure/active-directory/develop/v2-protocols-o
 =head1 AUTHOR
 
     Jose Luis Martinez
-    CAPSiDE
-    jlmartinez@capside.com
+    pplusdomain@gmail.com
+
+=head1 THANKS
+
+iamlgh for Client Credentials V2 module
 
 =head1 BUGS and SOURCE
 
@@ -43,7 +50,8 @@ Please report bugs to: L<https://github.com/pplu/azure-ad-auth/issues>
 
 =head1 COPYRIGHT and LICENSE
 
-Copyright (c) 2018 by CAPSiDE
+Copyright (c) 2020 by Jose Luis Martinez
+
 This code is distributed under the Apache 2 License. The full text of the 
 license can be found in the LICENSE file included with this module.
 
